
if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

set(_qt5Configuration_install_prefix "/usr/lib64/qt5")

# For backwards compatibility only. Use Qt5Configuration_VERSION instead.
set(Qt5Configuration_VERSION_STRING 0.1.0)

set(Qt5Configuration_LIBRARIES Qt5::Configuration)

macro(_qt5_Configuration_check_file_exists file)
    if(NOT EXISTS "${file}" )
        message(FATAL_ERROR "The imported target \"Qt5::Configuration\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()


macro(_populate_Configuration_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::Configuration APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set(imported_location "/usr/lib64/${LIB_LOCATION}")
    _qt5_Configuration_check_file_exists(${imported_location})
    set_target_properties(Qt5::Configuration PROPERTIES
        "INTERFACE_LINK_LIBRARIES" "${_Qt5Configuration_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        "IMPORTED_SONAME_${Configuration}" "libQt0Configuration.so.0"
        # For backward compatibility with CMake < 2.8.12
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5Configuration_LIB_DEPENDENCIES}"
    )

endmacro()

if (NOT TARGET Qt5::Configuration)

    set(_Qt5Configuration_OWN_INCLUDE_DIRS "/usr/include/qt5/" "/usr/include/qt5/QtConfiguration")
    set(Qt5Configuration_PRIVATE_INCLUDE_DIRS
        "/usr/include/qt5/QtConfiguration/0.1.0"
        "/usr/include/qt5/QtConfiguration/0.1.0/QtConfiguration"
    )

    foreach(_dir ${_Qt5Configuration_OWN_INCLUDE_DIRS})
        _qt5_Configuration_check_file_exists(${_dir})
    endforeach()

    # Only check existence of private includes if the Private component is
    # specified.
    list(FIND Qt5Configuration_FIND_COMPONENTS Private _check_private)
    if (NOT _check_private STREQUAL -1)
        foreach(_dir ${Qt5Configuration_PRIVATE_INCLUDE_DIRS})
            _qt5_Configuration_check_file_exists(${_dir})
        endforeach()
    endif()

    set(Qt5Configuration_INCLUDE_DIRS ${_Qt5Configuration_OWN_INCLUDE_DIRS})

    set(Qt5Configuration_DEFINITIONS -DQT_CONFIGURATION_LIB)
    set(Qt5Configuration_COMPILE_DEFINITIONS QT_CONFIGURATION_LIB)

    set(_Qt5Configuration_MODULE_DEPENDENCIES "DBus;Core")

    set(_Qt5Configuration_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5Configuration_FIND_REQUIRED)
        set(_Qt5Configuration_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5Configuration_FIND_DEPENDENCIES_QUIET)
    if (Qt5Configuration_FIND_QUIETLY)
        set(_Qt5Configuration_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5Configuration_FIND_VERSION_EXACT)
    if (Qt5Configuration_FIND_VERSION_EXACT)
        set(_Qt5Configuration_FIND_VERSION_EXACT EXACT)
    endif()

    set(Qt5Configuration_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5Configuration_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                0.1.0 ${_Qt5Configuration_FIND_VERSION_EXACT}
                ${_Qt5Configuration_DEPENDENCIES_FIND_QUIET}
                ${_Qt5Configuration_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5Configuration_FOUND False)
            return()
        endif()

        list(APPEND Qt5Configuration_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5Configuration_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5Configuration_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5Configuration_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5Configuration_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5Configuration_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5Configuration_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5Configuration_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5Configuration_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5Configuration_EXECUTABLE_COMPILE_FLAGS)

    set(_Qt5Configuration_LIB_DEPENDENCIES "Qt5::DBus;Qt5::Core")

    add_library(Qt5::Configuration SHARED IMPORTED)

    set_property(TARGET Qt5::Configuration PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5Configuration_OWN_INCLUDE_DIRS})
    set_property(TARGET Qt5::Configuration PROPERTY
      INTERFACE_COMPILE_DEFINITIONS QT_CONFIGURATION_LIB)

    _populate_Configuration_target_properties(RELEASE "libQt0Configuration.so.0.1.0" "" )







_qt5_Configuration_check_file_exists("${CMAKE_CURRENT_LIST_DIR}/Qt5ConfigurationConfigVersion.cmake")

endif()
